package goods

import (
	"applet/app/admin/md"
	"applet/app/db"
	"applet/app/db/model"
	"applet/app/svc"
	"applet/app/utils"
	"github.com/gin-gonic/gin"
	"xorm.io/xorm"
)

func GetSkuScheme(engine *xorm.Engine, EnterpriseId string, gids []string) map[int64]model.SchemeWithSku {
	var skuSchemeMap = make(map[int64]model.SchemeWithSku)
	if utils.StrToInt64(EnterpriseId) > 0 {
		var enterpriseScheme model.SchemeWithEnterprise
		engine.Where("enterprise_id=?", EnterpriseId).Get(&enterpriseScheme)
		if enterpriseScheme.SchemeId > 0 {
			var scheme model.Scheme
			engine.Where("id=?", enterpriseScheme.SchemeId).Get(&scheme)
			if scheme.State != 1 {
				return skuSchemeMap
			}
			var skuScheme []model.SchemeWithSku
			engine.In("goods_id", gids).And("scheme_id=?", enterpriseScheme.SchemeId).Find(&skuScheme)
			for _, v := range skuScheme {
				skuSchemeMap[v.SkuId] = v
			}
		}
	}
	return skuSchemeMap
}

// 获取列表数据
func GetMallGoodsListByPay(c *gin.Context, req *md.MallGoodsListReq) (interface{}, int64, error) {
	var goodsListResp []md.MallGoodListResp
	// 获取分库链接
	engine := db.Db
	// 查询goods数据表获取数据
	mallGoodsList, skus, total, err := db.GetMallGoodsListLeftOnMallSku(engine, req)
	if err != nil {
		return nil, 0, err
	}
	var tmpMap interface{}
	scheme, host, subDomain, moreSubDomain := svc.ImageBucketNew(c)

	if err != nil {
		return nil, 0, err
	}
	//判断是不是学校下单时的商品列表 计算对应的价格
	gids := make([]string, 0)
	for _, item := range mallGoodsList {
		gids = append(gids, item["goods_id"])
	}
	skuSchemeMap := GetSkuScheme(engine, req.EnterpriseId, gids)
	for _, item := range mallGoodsList {
		var goods md.MallGoodListResp
		goods.GoodsId = item["goods_id"]
		goods.SaleState = utils.StrToInt(item["sale_state"])
		goods.Sales = utils.StrToInt(item["sales"])
		goods.CreateAt = item["create_at"]

		// 商品主图
		if item["image_list"] != "" {
			utils.Unserialize([]byte(item["image_list"]), &tmpMap)
			var imageListUrlTmp []string
			for _, v := range tmpMap.([]interface{}) {
				imageListUrlTmp = append(imageListUrlTmp, svc.ImageFormatWithBucketNew(scheme, host, subDomain, moreSubDomain, v.(string)))
			}
			if imageListUrlTmp != nil {
				goods.Image = imageListUrlTmp[0]
			}
		}

		goods.UpdateAt = item["update_at"]
		goods.Title = item["title"]

		// 状态
		switch utils.StrToInt64(item["sale_state"]) {
		case 1.00:
			goods.SaleStateText = "銷售中"
			break
		case 2.00:
			goods.SaleStateText = "下架"
			break
		}

		// sku
		var minPrice float64 = utils.StrToFloat64(item["price"])
		for _, skuItem := range skus {
			if skuItem.GoodsId == utils.StrToInt64(item["goods_id"]) {
				//方案的价格
				skuScheme, ok := skuSchemeMap[skuItem.SkuId]
				if ok {
					skuItem.Price = skuScheme.Price
				}
				if minPrice > utils.StrToFloat64(skuItem.Price) {
					minPrice = utils.StrToFloat64(skuItem.Price)
				}
				goods.SkuList = append(goods.SkuList, skuItem)
			}
		}
		// 获取价格、库存、重量范围、利润空间
		goods.Price = utils.Float64ToStr(minPrice)
		// spe
		var spe []map[string]interface{}
		var speTmp []map[string]interface{}
		utils.Unserialize([]byte(item["spe"]), &spe)
		for _, itemSpe := range spe {
			tmp := make(map[string]interface{})
			tmp["type"] = "text"
			tmp["name"] = itemSpe["name"]
			subTmp := make([]map[string]interface{}, 0)
			for i, v := range itemSpe["values"].([]interface{}) {
				subTmp = append(subTmp, map[string]interface{}{
					"key":  i,
					"name": v,
				})
			}
			tmp["values"] = subTmp
			speTmp = append(speTmp, tmp)
		}
		goods.Spe = speTmp
		goodsListResp = append(goodsListResp, goods)
	}

	return goodsListResp, total, err
}
